# frozen_string_literal: true

module Bulkrax
  class RerunImportersController < ApplicationController
    include BulkraxHelper
    before_action :set_importer, only: [:rerun_failed_entries, :rerun_panding_entries, :marked_as_complete]

    def rerun_failed_entries
      total_rerun_entries = rerun_failed_or_pending_entries_in_last_run("Failed")
      flash[:notice] = "#{total_rerun_entries} failed jobs queued"
      redirect_to importers_path
    end

    def rerun_panding_entries
      total_rerun_entries = rerun_failed_or_pending_entries_in_last_run("Pending")
      flash[:notice] = "#{total_rerun_entries} pending jobs queued"
      redirect_to importers_path
    end

    def marked_as_complete
      @importer.last_run.update(enqueued_records: 0)
      @importer.status_info('Complete')

      redirect_to importers_path
    end

    private

    def set_importer
      @importer = Importer.find(params[:importer_id])
    end
  end
end
