module ComplexHelper
  def sanitize_title(title)
    return if title.nil?

    # remove extra spaces from beginning and end
    title = title.strip

    # Remove any characters other than a-z, 0-9, ., and -
    title.gsub!(/[^a-zA-Z0-9.\-\s]/, '')

    # Replace consecutive spaces with a single space
    title.gsub!(/\s+/, ' ')

    # Replace consecutive dots with a single dot
    title.gsub!(/\.{2,}/, '.')

    # Replace consecutive hyphens with a single hyphen
    title.gsub!(/-{2,}/, '-')

    # Bucket titles must begin and end with a letter or number
    title.sub!(/\A[^a-zA-Z0-9]*/, '')
    title.sub!(/[^a-zA-Z0-9]*\z/, '')

    title = title.downcase

    # Check for xn-- prefix and sthree- prefix
    title.gsub!(/\Asthree-/i, '')

    # Check for -s3alias suffix and --ol-s3 suffix
    title.sub!(/-s3alias\z/i, '')
    title
  end
  
  private

  def authorize
    case action_name
    when 'show'
      authorize! :show, @crc_dataset
    else
      authorize! :edit, @crc_dataset
    end
  end
end