# frozen_string_literal: true

class Ability
  include Hydra::Ability

  include Hyrax::Ability
  self.ability_logic += %i[
    everyone_can_create_curation_concerns
    create_content
    manage_roles
    manage_importer
    manage_exporter
    manage_review_submission
  ]

  # Define any customized permissions here.
  def custom_permissions
    return unless current_user.admin?

    can :manage, Role
    can :manage, ::User
    can :create, [::Dataset, ::CrcDataset]
  end

  def create_content
    return unless current_user

    can [:confirm_delete, :restore], [::Dataset, ::CrcDataset] if current_user.admin? || current_user.crc_manager?
    can [:create, :tombstone], [::Dataset, ::CrcDataset]
  end

  def manage_roles
    can %i[edit update show add_user remove_user], Role do |role|
      if role.is_crc_manager
        current_user.roles.where(name: role.name).any?
      elsif role.is_crc_member
        current_user.roles.where(name: role.name.gsub('_member', '_manager')).any?
      elsif role.is_crc_group_manager
        current_user.crc_manager_for?(role.name.split('_')[-2])
      elsif role.is_crc_group_member
        group_id = role.name.split('_')[-2]

        current_user.crc_manager_for?(group_id) || current_user.group_manager_for?(group_id)
      else
        false
      end
    end
  end

  def manage_importer
    return unless current_user.admin? || current_user.roles.where(is_crc_manager: true).present?

    can :manage, Bulkrax::Importer
  end

  def manage_exporter
    return unless current_user.admin? || current_user.roles.where(is_crc_manager: true).present?

    can :manage, Bulkrax::Exporter
  end

  def manage_review_submission
    if current_user.admin? || current_user.crc_manager? || current_user.crc_group_manager? || current_user.publication_manager?
      can :review, :submissions
    end 
  end
end
