# frozen_string_literal: true

Bulkrax.setup do |config|
  # Add local parsers
  config.parsers += [
    { name: 'CRC folder parser - Build csv from directory data', class_name: 'Bulkrax::CrcFolderParser', partial: 'crc_folder_fields' },
    { name: 'CSV from S3 - ReSeed CSV parser for work (Datasets) from local S3', class_name: 'Bulkrax::RubCsvParser', partial: 'rub_csv_fields' }
  ]

  config.default_work_type = 'CrcDataset'

  config.field_mappings = {
    "Bulkrax::CrcFolderParser" => {
      "date_created" => { from: ["date"] },
      "description" => { from: ["description"] },
      "identifier" => { from: ["identifier"] },
      "language" => { from: ["language"], parsed: true },
      "publisher" => { from: ["publisher"] },
      "rights_statement" => { from: ["rights"] },
      "source" => { from: ["source"], source_identifier: true },
      "subject" => { from: ["subject"], parsed: true },
      "title" => { from: ["title"] },
      "resource_type" => { from: ["type"], parsed: true },
      "remote_files" => { from: ["thumbnail_url"], parsed: true },
      "abstract" => { from: ["abstract"] },
      "keyword" => { from: ["keyword"] },
      "crc_resource_type" => { from: ["crc resource type"] },
      "crc_work_type" => { from: ["crc work type"] },
      "folder_name" => { from: ["folder_name"] },
      "experiment_description" => { from: ["experiment_description"] },
      "for_complex_identifier" => { from: ["for_complex_identifier"] },
      "for_complex_type" => { from: ["for_complex_type"] },
      'parents' => { from: ['parents'], related_parents_field_mapping: true },
      'children' => { from: ['children'], related_children_field_mapping: true }
    },

    "Bulkrax::RubCsvParser" => {
      "title" => { from: ["title"], source_identifier: true},
      "description" => { from: ["description"] },
      "resource_type" => { from: ["resource_type"], parsed: true },
      "keyword" => { from: ["keyword"] },
      "alternative_title" => { from: ["alternative_title"] },
      "subject" => { from: ["subject"], parsed: true },
      "language" => { from: ["language"], parsed: true },
      "software_version" => { from: ["software_version"] },
      "dataset_path" => {from: ["dataset_path"]}
    }
  }
end
