# frozen_string_literal: true
namespace :rdms do
  desc "Fix metadata in S3 for all works. usage: rdms:fix_metadata_in_s3"
  task fix_metadata_in_s3: :environment do
    all_works = %w(Dataset CrcDataset ComplexSubject ComplexSession ComplexModality)
    all_works.each do |work_type|
      work_type.constantize.all.each do |w|
        # Save the metadata.json file along with system_metadata.json
        puts "Saving metadata for #{work_type} #{w.id}"
        case work_type
        when 'Dataset', 'CrcDataset'
          begin
            w.save_metadata_as_json_in_s3
          rescue
            puts "error saving metadata for #{work_type} #{w.id}"
          end
        else
          begin
            w.send(:save_metadata_as_json_in_s3)
          rescue
            puts "error saving metadata for #{work_type} #{w.id}"
          end
        end
        if work_type == "CrcDataset"
          # save meta.json for modalities
          puts "Saving meta.json for #{work_type} #{w.id}"
          begin
            w.save_meta_json_in_s3
          rescue
            puts "error saving metadata for #{work_type} #{w.id}"
          end
        end
      end
    end
  end
end
